@@ -23,6 +23,8 @@ autodoc_default_options = {
     "members": True,
     "undoc-members": True,
 }
+codeautolink_warn_on_missing_inventory = True
+codeautolink_warn_on_failed_resolve = True
 """
 
 any_whitespace = re.compile(r"\s*")
